// Load the data
d3.text(
  'https://gist.githubusercontent.com/Mahesh-Polisetty/b1c964bd124c3b2136baad7baf748242/raw/f5132d35d88dc23d9cd5d89c693c4c815126b7d4/Assignment5.csv',
).then(function (text) {
  // Split the text into lines
  const lines = text.split('\n');

  // Initialize an empty array to store the data
  const data = [];

  // Parse each line and extract job title and salary
  lines.forEach(function (line) {
    if (line.trim() !== '') {
      const parts = line.split(',');
      const Title = parts[0];
      const Score = +parts[1]; // Convert salary to a number
      data.push({ Title: Title, Score: Score });
    }
  });

  // Proceed to create the chart using the fetched data

  // Set up the dimensions of the chart
  const width = 1200;
  const height = 500;
  const margin = {
    top: 40,
    right: 50,
    bottom: 120,
    left: 60,
  };

  // Create the SVG container
  const svg = d3
    .select('#chart')
    .append('svg')
    .attr('width', width)
    .attr('height', height);

  // Create scales
  const xScale = d3
    .scaleBand()
    .domain(data.map((d) => d.Title))
    .range([margin.left, width - margin.right])
    .padding(0.02); // Decrease padding to make bars wider

  const yScale = d3
    .scaleLinear()
    .domain([0, d3.max(data, (d) => d.Score)])
    .nice()
    .range([height - margin.bottom, margin.top]);

  // Create bars with tooltips
  svg
    .selectAll('rect')
    .data(data)
    .enter()
    .append('rect')
    .attr('x', (d) => xScale(d.Title))
    .attr('y', (d) => yScale(d.Score))
    .attr('width', xScale.bandwidth())
    .attr(
      'height',
      (d) => height - margin.bottom - yScale(d.Score),
    )
    .attr('fill', 'steelblue')
    // Add tooltip on mouseover
    .on('mouseover', function (d) {
      // Change color of the bar on hover
      d3.select(this).attr('fill', 'yellow');

      // Show tooltip
      const tooltip = d3.select('#tooltip');
      tooltip
        .style('visibility', 'visible')
        .html(
          `<strong>${d.Title}</strong><br>Salary: $${d.Score.toLocaleString()}`,
        );
    })
    // Restore original color on mouseout
    .on('mouseout', function (d) {
      // Restore original color of the bar
      d3.select(this).attr('fill', 'blue');

      // Hide tooltip
      d3.select('#tooltip').style('visibility', 'hidden');
    });

  // Add x-axis
  svg
    .append('g')
    .attr(
      'transform',
      `translate(0,${height - margin.bottom})`,
    )
    .call(d3.axisBottom(xScale))
    .selectAll('text')
    .attr('transform', 'rotate(-90)')
    .style('text-anchor', 'end')
    .attr('dx', '-.8em')
    .attr('dy', '.15em'); // These are optional adjustments for further fine-tuning

  // Add x-axis name label
  svg
    .append('text')
    .attr('class', 'x label')
    .attr('text-anchor', 'end')
    .attr('x', width)
    .attr('y', height - 100)
    .text('Title');

  // Add y-axis
  svg
    .append('g')
    .attr('transform', `translate(${margin.left},0)`)
    .call(d3.axisLeft(yScale));

  // Add y-axis name label
  svg
    .append('text')
    .attr('class', 'y label')
    .attr('text-anchor', 'end')
    .attr('y', 40)
    .attr('dy', '1em')
    .attr('transform', 'rotate(-90)')
    .text('Score');

  // Add chart title
  svg
    .append('text')
    .attr('x', width / 2)
    .attr('y', margin.top / 2)
    .attr('text-anchor', 'middle')
    .style('font-size', '16px')
    .text('Anime vs rating from ICE 5');

  // Add tooltip container
  d3.select('#chart')
    .append('div')
    .attr('id', 'tooltip')
    .style('position', 'absolute')
    .style('visibility', 'hidden')
    .style('background-color', 'rgba(255, 255, 255, 0.8)')
    .style('padding', '5px')
    .style('border-radius', '5px')
    .style('box-shadow', '0 0 10px rgba(0, 0, 0, 0.2)');
});
